==> haskell-recursion-schemes-5.2.3-119-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-recursion-schemes.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 recursion-schemes
version:              5.2.3
visibility:           public
id:                   recursion-schemes-5.2.3-6ADlAotBHfnJbr5fy9ZDVM
key:                  recursion-schemes-5.2.3-6ADlAotBHfnJbr5fy9ZDVM
license:              BSD-2-Clause
copyright:            Copyright (C) 2008-2015 Edward A. Kmett
maintainer:
    "Samuel Gélineau" <gelisam@gmail.com>,
    "Ryan Scott" <ryan.gl.scott@gmail.com>,
    "Luc Tielen" <luc.tielen@gmail.com>

author:               Edward A. Kmett
stability:            provisional
homepage:             http://github.com/ekmett/recursion-schemes/
synopsis:
    Representing common recursion patterns as higher-order functions

description:
    Many recursive functions share the same structure, e.g. pattern-match on the input and, depending on the data constructor, either recur on a smaller input or terminate the recursion with the base case. Another one: start with a seed value, use it to produce the first element of an infinite list, and recur on a modified seed in order to produce the rest of the list. Such a structure is called a recursion scheme. Using higher-order functions to implement those recursion schemes makes your code clearer, faster, and safer. See README for details.

category:             Control, Recursion
abi:                  56ff789c1106d72cf19c475dd76b3c8d
exposed:              True
exposed-modules:
    Data.Functor.Base Data.Functor.Foldable Data.Functor.Foldable.TH

hidden-modules:       Paths_recursion_schemes
import-dirs:          /usr/lib/ghc-9.4.8/site-local/recursion-schemes-5.2.3
library-dirs:         /usr/lib/ghc-9.4.8/site-local/recursion-schemes-5.2.3
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/recursion-schemes-5.2.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-recursion-schemes
hs-libraries:         HSrecursion-schemes-5.2.3-6ADlAotBHfnJbr5fy9ZDVM
depends:
    base-4.17.2.1 comonad-5.0.9-9XYCuoUxdGmGG2uu9BeGYY containers-0.6.7
    data-fix-0.3.4-20jbuwOv5b08CP4WjwaM8i
    free-5.2-FO2Q20euwXcCdGr9UaAYL8 template-haskell-2.19.0.0
    th-abstraction-0.5.0.0-BROQwjXmGCt8uLmQUfLqOy transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-recursion-schemes/html/recursion-schemes.haddock

haddock-html:         /usr/share/doc/haskell-recursion-schemes/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-recursion-schemes-5.2.3-120-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-recursion-schemes.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 recursion-schemes
version:              5.2.3
visibility:           public
id:                   recursion-schemes-5.2.3-9EYcfQbqDJW6OwQI6wfam7
key:                  recursion-schemes-5.2.3-9EYcfQbqDJW6OwQI6wfam7
license:              BSD-2-Clause
copyright:            Copyright (C) 2008-2015 Edward A. Kmett
maintainer:
    "Samuel Gélineau" <gelisam@gmail.com>,
    "Ryan Scott" <ryan.gl.scott@gmail.com>,
    "Luc Tielen" <luc.tielen@gmail.com>

author:               Edward A. Kmett
stability:            provisional
homepage:             http://github.com/ekmett/recursion-schemes/
synopsis:
    Representing common recursion patterns as higher-order functions

description:
    Many recursive functions share the same structure, e.g. pattern-match on the input and, depending on the data constructor, either recur on a smaller input or terminate the recursion with the base case. Another one: start with a seed value, use it to produce the first element of an infinite list, and recur on a modified seed in order to produce the rest of the list. Such a structure is called a recursion scheme. Using higher-order functions to implement those recursion schemes makes your code clearer, faster, and safer. See README for details.

category:             Control, Recursion
abi:                  c6a36c81b7af2de0051e76fcc3924fa7
exposed:              True
exposed-modules:
    Data.Functor.Base Data.Functor.Foldable Data.Functor.Foldable.TH

hidden-modules:       Paths_recursion_schemes
import-dirs:          /usr/lib/ghc-9.4.8/site-local/recursion-schemes-5.2.3
library-dirs:         /usr/lib/ghc-9.4.8/site-local/recursion-schemes-5.2.3
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/recursion-schemes-5.2.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-recursion-schemes
hs-libraries:         HSrecursion-schemes-5.2.3-9EYcfQbqDJW6OwQI6wfam7
depends:
    base-4.17.2.1 comonad-5.0.9-HhbbzCqu8yXCinyU8dzPDS containers-0.6.7
    data-fix-0.3.4-JRPy6XMSABz3hA3MUzO3vc
    free-5.2-4BhqVm0YwcdLhUwvBUyNs8 template-haskell-2.19.0.0
    th-abstraction-0.5.0.0-BROQwjXmGCt8uLmQUfLqOy transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-recursion-schemes/html/recursion-schemes.haddock

haddock-html:         /usr/share/doc/haskell-recursion-schemes/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
